@@ -115,7 +115,11 @@ class fMMS_ConfigDialog():
 		dialog.destroy()
 
 	def show_apn_config(self, button, dialog):
-		apndialog = APNConfigDialog(dialog)
+		try:
+			apndialog = APNConfigDialog(dialog)
+		except:
+			log.exception("APN Config died.")
+			raise
 		
 	def conn_mode_toggled(self, widget):
 		""" Ugly hack used since its ToggleButtons """
@@ -210,7 +214,7 @@ class APNConfigDialog():
 			label.set_width_chars(labelwidth)
 			vars()[var] = gtk.Entry()
 			if current:
-				if current[var]:
+				if current.get(var, None):
 					vars()[var].set_text(str(current[var]))
 			entries[var] = vars()[var]
 			box.pack_start(label, False, True, 0)
@@ -269,7 +273,7 @@ class APNConfigDialog():
 			label.set_width_chars(labelwidth)
 			vars()[var] = gtk.Entry()
 			if current:
-				if current[var]:
+				if current.get(var, None):
 					vars()[var].set_text(str(current[var]))
 			entries[var] = vars()[var]
 			box.pack_start(label, False, True, 0)
